@@ -14,12 +14,11 @@
 #' @param auxiliary The list of variables to be considered as auxiliary (i.e., retained in the dataset but not used in the analysis). Defaults to NULL.
 #' @param ID The variable which identifies cases. Defaults to NULL.
 #' @param thresholds A Boolean operator indicating whether to test for threshold DIF.
-#' @return A object of type aMNLFA.object, which is a list of all the above arguments that can be passed to each aMNLFA function (except aMNLFA_DIFplot, which takes the output from aMNLFA.prune()).
 #' @keywords MNLFA
 #' @export
 #' @examples
 #'  wd <- tempdir()
-#'  first<-paste0(system.file(package='aMNLFA'),"/extdata")
+#'  first<-paste0(system.file(package='aMNLFA'),"/examplefiles")
 #'  the.list <- list.files(first,full.names=TRUE)
 #'  file.copy(the.list,wd,overwrite=TRUE)
 #'  
@@ -39,7 +38,11 @@ aMNLFA.object<-function(dir, mrdata, indicators=NULL, catindicators=NULL, counti
   charOrNull <- function(x) {
     is.character(x) || is.null(x)
   }
-
+  
+  if (thresholds == TRUE) {
+    stop("thresholds == TRUE is disabled in this version of aMNLFA. Reset thresholds to FALSE to run this function.")
+  }
+  
   stopifnot(charOrNull(indicators))
   stopifnot(charOrNull(catindicators))
   stopifnot(charOrNull(countindicators))
